@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2018,2020,2024 Daniel Estevez <daniel@destevez.net>
+ * Copyright 2018,2020 Daniel Estevez <daniel@destevez.net>
  *
  * This file is part of gr-satellites
  *
@@ -17,7 +17,6 @@
 
 #include <boost/format.hpp>
 #include <algorithm>
-#include <cstdint>
 #include <exception>
 
 extern "C" {
@@ -34,12 +33,6 @@ encode_rs::sptr encode_rs::make(bool dual_basis, int interleave)
     return gnuradio::get_initial_sptr(new encode_rs_impl(dual_basis, interleave));
 }
 
-encode_rs::sptr encode_rs::make(int frame_size, bool dual_basis, int interleave)
-{
-    return gnuradio::get_initial_sptr(
-        new encode_rs_impl(frame_size, dual_basis, interleave));
-}
-
 encode_rs::sptr
 encode_rs::make(int symsize, int gfpoly, int fcr, int prim, int nroots, int interleave)
 {
@@ -47,40 +40,13 @@ encode_rs::make(int symsize, int gfpoly, int fcr, int prim, int nroots, int inte
         new encode_rs_impl(symsize, gfpoly, fcr, prim, nroots, interleave));
 }
 
-encode_rs::sptr encode_rs::make(int frame_size,
-                                int symsize,
-                                int gfpoly,
-                                int fcr,
-                                int prim,
-                                int nroots,
-                                int interleave)
-{
-    return gnuradio::get_initial_sptr(
-        new encode_rs_impl(frame_size, symsize, gfpoly, fcr, prim, nroots, interleave));
-}
-
+/*
+ * The private constructor
+ */
 encode_rs_impl::encode_rs_impl(bool dual_basis, int interleave)
-    : gr::sync_block(
+    : gr::block(
           "encode_rs", gr::io_signature::make(0, 0, 0), gr::io_signature::make(0, 0, 0)),
-      d_interleave(interleave),
-      d_frame_size(0)
-{
-    setup_ccsds(dual_basis);
-    set_message_ports();
-}
-
-encode_rs_impl::encode_rs_impl(int frame_size, bool dual_basis, int interleave)
-    : gr::sync_block("encode_rs",
-                     gr::io_signature::make(1, 1, frame_size),
-                     gr::io_signature::make(1, 1, d_ccsds_nn * interleave)),
-      d_interleave(interleave),
-      d_frame_size(frame_size)
-{
-    check_frame_size();
-    setup_ccsds(dual_basis);
-}
-
-void encode_rs_impl::setup_ccsds(bool dual_basis)
+      d_interleave(interleave)
 {
     static constexpr int parity_offset = d_ccsds_nn - d_ccsds_nroots;
     if (dual_basis) {
@@ -94,37 +60,17 @@ void encode_rs_impl::setup_ccsds(bool dual_basis)
     d_nroots = d_ccsds_nroots;
 
     check_interleave();
-}
-
-encode_rs_impl::encode_rs_impl(
-    int symsize, int gfpoly, int fcr, int prim, int nroots, int interleave)
-    : gr::sync_block(
-          "encode_rs", gr::io_signature::make(0, 0, 0), gr::io_signature::make(0, 0, 0)),
-      d_interleave(interleave),
-      d_frame_size(0)
-{
-    setup_generic(symsize, gfpoly, fcr, prim, nroots);
     set_message_ports();
 }
 
-encode_rs_impl::encode_rs_impl(int frame_size,
-                               int symsize,
-                               int gfpoly,
-                               int fcr,
-                               int prim,
-                               int nroots,
-                               int interleave)
-    : gr::sync_block("encode_rs",
-                     gr::io_signature::make(1, 1, frame_size),
-                     gr::io_signature::make(1, 1, ((1U << symsize) - 1) * interleave)),
-      d_interleave(interleave),
-      d_frame_size(frame_size)
-{
-    check_frame_size();
-    setup_generic(symsize, gfpoly, fcr, prim, nroots);
-}
-
-void encode_rs_impl::setup_generic(int symsize, int gfpoly, int fcr, int prim, int nroots)
+/*
+ * The private constructor
+ */
+encode_rs_impl::encode_rs_impl(
+    int symsize, int gfpoly, int fcr, int prim, int nroots, int interleave)
+    : gr::block(
+          "encode_rs", gr::io_signature::make(0, 0, 0), gr::io_signature::make(0, 0, 0)),
+      d_interleave(interleave)
 {
     d_rs_p = init_rs_char(symsize, gfpoly, fcr, prim, nroots, 0);
     const int codeword_size = (1U << symsize) - 1;
@@ -140,6 +86,7 @@ void encode_rs_impl::setup_generic(int symsize, int gfpoly, int fcr, int prim, i
     d_nroots = nroots;
 
     check_interleave();
+    set_message_ports();
 }
 
 void encode_rs_impl::check_interleave()
@@ -150,13 +97,6 @@ void encode_rs_impl::check_interleave()
     }
 }
 
-void encode_rs_impl::check_frame_size()
-{
-    if (d_frame_size % d_interleave != 0) {
-        throw std::runtime_error("Interleave must divide frame size");
-    }
-}
-
 void encode_rs_impl::set_message_ports()
 {
     message_port_register_out(pmt::mp("out"));
@@ -164,6 +104,9 @@ void encode_rs_impl::set_message_ports()
     set_msg_handler(pmt::mp("in"), [this](pmt::pmt_t msg) { this->msg_handler(msg); });
 }
 
+/*
+ * Our virtual destructor.
+ */
 encode_rs_impl::~encode_rs_impl()
 {
     if (d_rs_p) {
@@ -171,35 +114,14 @@ encode_rs_impl::~encode_rs_impl()
     }
 }
 
-int encode_rs_impl::work(int noutput_items,
-                         gr_vector_const_void_star& input_items,
-                         gr_vector_void_star& output_items)
+void encode_rs_impl::forecast(int noutput_items, gr_vector_int& ninput_items_required) {}
+
+int encode_rs_impl::general_work(int noutput_items,
+                                 gr_vector_int& ninput_items,
+                                 gr_vector_const_void_star& input_items,
+                                 gr_vector_void_star& output_items)
 {
-    auto in = static_cast<const uint8_t*>(input_items[0]);
-    auto out = static_cast<uint8_t*>(output_items[0]);
-
-    const auto rs_kk = d_frame_size / d_interleave;
-    const auto pad = d_rs_codeword.size() - rs_kk - d_nroots;
-    const auto output_frame_size = d_rs_codeword.size() * d_interleave;
-
-    for (int i = 0; i < noutput_items; ++i) {
-        for (int j = 0; j < d_interleave; ++j) {
-            std::fill(d_rs_codeword.begin(), d_rs_codeword.begin() + pad, 0);
-            for (int k = 0; k < rs_kk; ++k) {
-                d_rs_codeword[pad + k] = in[j + k * d_interleave];
-            }
-
-            d_encode_rs(d_rs_codeword.data());
-
-            for (int k = 0; k < rs_kk + d_nroots; ++k) {
-                out[j + k * d_interleave] = d_rs_codeword[pad + k];
-            }
-        }
-        in += d_frame_size;
-        out += output_frame_size;
-    }
-
-    return noutput_items;
+    return 0;
 }
 
 void encode_rs_impl::msg_handler(pmt::pmt_t pmt_msg)
