@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2018 Daniel Estevez <daniel@destevez.net>
+ * Copyright 2018,2020 Daniel Estevez <daniel@destevez.net>
  *
  * This file is part of gr-satellites
  *
@@ -13,9 +13,9 @@
 
 #include <satellites/encode_rs.h>
 
-#include <array>
-
-#include "rs.h"
+#include <cstdint>
+#include <functional>
+#include <vector>
 
 namespace gr {
 namespace satellites {
@@ -23,11 +23,24 @@ namespace satellites {
 class encode_rs_impl : public encode_rs
 {
 private:
-    const int d_basis;
-    std::array<uint8_t, MAX_FRAME_LEN> d_data;
+    int d_interleave;
+    std::vector<uint8_t> d_rs_codeword;
+    std::vector<uint8_t> d_output_frame;
+    int d_nroots;
+    void* d_rs_p = NULL;
+
+    std::function<void(uint8_t*)> d_encode_rs;
+
+    constexpr static int d_ccsds_nn = 255;
+    constexpr static int d_ccsds_nroots = 32;
+
+    void check_interleave();
+    void set_message_ports();
 
 public:
-    encode_rs_impl(int basis);
+    encode_rs_impl(bool dual_basis, int interleave = 1);
+    encode_rs_impl(
+        int symsize, int gfpoly, int fcr, int prim, int nroots, int interleave = 1);
     ~encode_rs_impl();
 
     // Where all the action really happens
