@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright 2020-2025 Daniel Estevez <daniel@destevez.net>
+# Copyright 2020-2021 Daniel Estevez <daniel@destevez.net>
 #
 # This file is part of gr-satellites
 #
@@ -19,11 +19,11 @@ stack, the AO-40 protocol used in the FUNcube satellites, and several
 ad-hoc protocols used in other satellites.
 """
 
-__version__ = 'v3.22.0'
+__version__ = 'v4.4.0'
 __author__ = 'Daniel Estevez'
-__copyright__ = 'Copyright 2016-2025 Daniel Estevez'
+__copyright__ = 'Copyright 2016-2021 Daniel Estevez'
 __email__ = 'daniel@destevez.net'
-__license__ = 'GPL-3.0-or-later'
+__license__ = 'GPL-3.0'
 __all__ = [
     'ccsds',
     'components',
@@ -36,22 +36,20 @@ __all__ = [
     'utils',
     ]
 
-# import swig generated symbols into the satellites namespace
-# this would fail if we are being imported from the build dir
+# Import bindings into the satellites namespace.
+# The first try works when we are importing from the build dir
 try:
-    from .satellites_swig import *
-except ImportError:
-    from satellites_swig import *
+    from .bindings.satellites_python import *
+except ModuleNotFoundError:
+    from .satellites_python import *
 
 # Import any pure python here
 
 from .aausat4_remove_fsm import aausat4_remove_fsm
 from .adsb_kml import adsb_kml
 from .append_crc32c import append_crc32c
-from .autopolarization import autopolarization
 from .beesat_classifier import beesat_classifier
 from .bme_submitter import bme_submitter
-from .bme_ws_submitter import bme_ws_submitter
 from .cc11xx_packet_crop import cc11xx_packet_crop
 from .check_address import check_address
 from .check_ao40_uncoded_crc import check_ao40_uncoded_crc
@@ -61,12 +59,8 @@ from .check_crc16_ccitt import check_crc16_ccitt
 from .check_crc16_ccitt_false import check_crc16_ccitt_false
 from .check_crc import check_crc
 from .check_eseo_crc import check_eseo_crc
-from .check_hex_string import check_hex_string
 from .check_swiatowid_crc import check_swiatowid_crc
 from .check_tt64_crc import check_tt64_crc
-from .csp_address_filter import csp_address_filter
-from .csp_zmq_pub import csp_zmq_pub
-from .csp_zmq_sub import csp_zmq_sub
 from .eseo_line_decoder import eseo_line_decoder
 from .eseo_packet_crop import eseo_packet_crop
 from .fixedlen_tagger import fixedlen_tagger
@@ -77,6 +71,7 @@ from .k2sat_deframer import k2sat_deframer
 from .kiss_to_pdu import kiss_to_pdu
 from .ks1q_header_remover import ks1q_header_remover
 from .lilacsat1_gps_kml import lilacsat1_gps_kml
+from .manchester_sync import manchester_sync
 from .ngham_check_crc import ngham_check_crc
 from .ngham_packet_crop import ngham_packet_crop
 from .ngham_remove_padding import ngham_remove_padding
