@@ -17,18 +17,17 @@ import pmt
 
 class check_address(gr.basic_block):
     """docstring for block check_address"""
-    def __init__(self, address, direction, digicallsign=''):
+    def __init__(self, address, direction):
         gr.basic_block.__init__(
             self,
             name='check_address',
             in_sig=[],
             out_sig=[])
 
-        a = address.rsplit('-', 1)
+        a = address.split('-')
         self.callsign = a[0]
         self.ssid = int(a[1]) if len(a) > 1 else None
         self.direction = direction
-        self.digicallsign = digicallsign
 
         self.message_port_register_in(pmt.intern('in'))
         self.set_msg_handler(pmt.intern('in'), self.handle_msg)
@@ -53,32 +52,14 @@ class check_address(gr.basic_block):
         else:
             address = packet[7:14]
 
-        hbit = 0
-        if len(packet) > 20:
-
-            hbit = packet[20] >> 7
-# digi callsign; and above: hbit  (most significant bit after digi callsign)
-# (set to 1 in case of digipeated message)
-            digi = [c >> 1 for c in packet[14:20]]
-
-            digi = bytes(digi).decode('ascii').rstrip(' ')
-
-# extension bit (least significant bit after sender callsign)
-# (set to 0 in case of digi callsign follows)
-        ebit = packet[13] & 0x01
-
         callsign = [c >> 1 for c in address[:6]]
-
         callsign = bytes(callsign).decode('ascii').rstrip(' ')
-
         ssid = (address[6] >> 1) & 0x0f
 
-# altered if sentence
-        if ((callsign == self.callsign
-                and (self.ssid is None or ssid == self.ssid))
-                or (ebit == 0 and hbit == 1 and digi == self.digicallsign)):
-            # match
-            self.message_port_pub(pmt.intern('ok'), msg_pmt)
-        else:
-            # no match
+        if (callsign != self.callsign
+                or (self.ssid is not None and ssid != self.ssid)):
+            # Incorrect address
             self.message_port_pub(pmt.intern('fail'), msg_pmt)
+        else:
+            # Correct address
+            self.message_port_pub(pmt.intern('ok'), msg_pmt)
