@@ -81,7 +81,7 @@ class check_tt64_crc(gr.basic_block):
         if not pmt.is_u8vector(msg):
             print('[ERROR] Received invalid message type. Expected u8vector')
             return
-        packet = bytes(pmt.u8vector_elements(msg))
+        packet = pmt.u8vector_elements(msg)
 
         if self.packet_len is not None:
             packet = packet[:self.packet_len]
