@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright 2019, 2022 Daniel Estevez <daniel@destevez.net>
+# Copyright 2019 Daniel Estevez <daniel@destevez.net>
 #
 # This file is part of gr-satellites
 #
@@ -11,8 +11,7 @@
 from gnuradio import gr, blocks, digital
 
 from ... import (
-    decode_rs, ngham_packet_crop, ngham_remove_padding)
-from ...crcs import crc16_ccitt_x25
+    decode_rs, ngham_packet_crop, ngham_remove_padding, ngham_check_crc)
 from ...hier.sync_to_pdu_packed import sync_to_pdu_packed
 from ...hier.ccsds_descrambler import ccsds_descrambler
 from ...utils.options_block import options_block
@@ -64,7 +63,7 @@ class ngham_deframer(gr.hier_block2, options_block):
         self.tag2pdu = blocks.tagged_stream_to_pdu(blocks.byte_t, 'packet_len')
         self.scrambler = ccsds_descrambler()
         self.padding = ngham_remove_padding()
-        self.crc = crc16_ccitt_x25(swap_endianness=False)
+        self.crc = ngham_check_crc(self.options.verbose_crc)
 
         self.connect(self, self.slicer, self.deframer)
         self.msg_connect((self.deframer, 'out'), (self.crop, 'in'))
@@ -87,3 +86,7 @@ class ngham_deframer(gr.hier_block2, options_block):
             '--syncword_threshold', type=int,
             default=cls._default_sync_threshold,
             help='Syncword bit errors [default=%(default)r]')
+        parser.add_argument(
+            '--verbose_rs', action='store_true', help='Verbose RS decoder')
+        parser.add_argument(
+            '--verbose_crc', action='store_true', help='Verbose CRC check')
