@@ -13,7 +13,7 @@ from gnuradio import blocks
 from gnuradio import digital
 from gnuradio import gr
 from gnuradio.filter import firdes
-from .. import fixedlen_to_pdu
+import satellites
 import numpy
 
 
@@ -38,21 +38,27 @@ class sync_to_pdu(gr.hier_block2):
         ##################################################
         # Blocks
         ##################################################
-        self.fixedlen_to_pdu = fixedlen_to_pdu(
-                blocks.byte_t, 'syncword', packlen)
+        self.satellites_fixedlen_tagger_0_0_0 = (
+            satellites.fixedlen_tagger('syncword', 'packet_len',
+                                       packlen, numpy.byte))
         self.digital_correlate_access_code_tag_bb_0_0_0 = (
             digital.correlate_access_code_tag_bb(sync, threshold, 'syncword'))
+        self.blocks_tagged_stream_to_pdu_0_0_0 = (
+            blocks.tagged_stream_to_pdu(blocks.byte_t, 'packet_len'))
 
         ##################################################
         # Connections
         ##################################################
         self.msg_connect(
-            (self.fixedlen_to_pdu, 'pdus'), (self, 'out'))
+            (self.blocks_tagged_stream_to_pdu_0_0_0, 'pdus'), (self, 'out'))
         self.connect(
             (self.digital_correlate_access_code_tag_bb_0_0_0, 0),
-            self.fixedlen_to_pdu)
+            (self.satellites_fixedlen_tagger_0_0_0, 0))
         self.connect(
             (self, 0), (self.digital_correlate_access_code_tag_bb_0_0_0, 0))
+        self.connect(
+            (self.satellites_fixedlen_tagger_0_0_0, 0),
+            (self.blocks_tagged_stream_to_pdu_0_0_0, 0))
 
     def get_packlen(self):
         return self.packlen
