@@ -8,19 +8,19 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
 
-import numpy
 from gnuradio import gr
+import numpy
 import pmt
 
 from . import csp_header
 
+
 class print_header(gr.basic_block):
-    """
-    Print the CSP header of a CSP packet
-    """
+    """Print the CSP header of a CSP packet"""
     def __init__(self):
-        gr.basic_block.__init__(self,
-            name="print_header",
+        gr.basic_block.__init__(
+            self,
+            name='print_header',
             in_sig=[],
             out_sig=[])
 
@@ -30,12 +30,10 @@ class print_header(gr.basic_block):
     def handle_msg(self, msg_pmt):
         msg = pmt.cdr(msg_pmt)
         if not pmt.is_u8vector(msg):
-            print("[ERROR] Received invalid message type. Expected u8vector")
+            print('[ERROR] Received invalid message type. Expected u8vector')
             return
         packet = bytes(pmt.u8vector_elements(msg))
         try:
             print(csp_header.CSP(packet[:4]))
         except ValueError as e:
             print(e)
-
-
