@@ -21,7 +21,7 @@ gr_satellites FUNcube-1 --wavfile satellite-recordings/ao73.wav
 echo "Reaktor Hello World"
 gr_satellites "Reaktor Hello World" --wavfile satellite-recordings/reaktor_hello_world.wav 
 echo "S-NET A"
-gr_satellites "S-NET A" --wavfile satellite-recordings/snet_a.wav
+gr_satellites "S-NET A" --wavfile satellite-recordings/snet_a.wav --clk_bw 0.1
 echo "Swiatowid"
 gr_satellites Swiatowid --wavfile satellite-recordings/swiatowid.wav
 echo "NuSat"
@@ -117,5 +117,3 @@ echo "IDEASSat"
 gr_satellites IDEASSat --wavfile satellite-recordings/ideassat.wav
 echo "CAPE-3"
 gr_satellites CAPE-3 --wavfile satellite-recordings/cape3.wav
-echo "SanoSat-1"
-gr_satellites SanoSat-1 --wavfile satellite-recordings/sanosat1.wav
